@@ -59,7 +59,7 @@ if TYPE_CHECKING:
     from .cache import _Stack
     from .callbacks import PeriodicCallback
     from .location import Location
-    from .notifications import NotificationArea
+    from .notifications import NotificationAreaBase
     from .server import StoppableThread
 
     T = TypeVar("T")
@@ -158,8 +158,8 @@ class _state(param.Parameterized):
     _locations: ClassVar[WeakKeyDictionary[Document, Location]] = WeakKeyDictionary() # Server locations indexed by document
 
     # Notifications
-    _notification: ClassVar[NotificationArea | None] = None # Global location, e.g. for notebook context
-    _notifications: ClassVar[WeakKeyDictionary[Document, NotificationArea]] = WeakKeyDictionary() # Server notifications indexed by document
+    _notification: ClassVar[NotificationAreaBase | None] = None # Global location, e.g. for notebook context
+    _notifications: ClassVar[WeakKeyDictionary[Document, NotificationAreaBase]] = WeakKeyDictionary() # Server notifications indexed by document
 
     # Templates
     _template: ClassVar[BaseTemplate | None] = None
@@ -235,6 +235,9 @@ class _state(param.Parameterized):
     # Watchers
     _watch_events: ClassVar[list[asyncio.Event]] = []
 
+    # Types
+    _notification_type: ClassVar[type[NotificationAreaBase] | None] = None
+
     def __repr__(self) -> str:
         server_info = []
         for server, panel, _docs in self._servers.values():
@@ -1119,7 +1122,7 @@ class _state(param.Parameterized):
         return log_terminal
 
     @property
-    def notifications(self) -> NotificationArea | None:
+    def notifications(self) -> NotificationAreaBase | None:
         if self.curdoc is None:
             return self._notification
 
@@ -1131,13 +1134,17 @@ class _state(param.Parameterized):
         if not (config.notifications and is_session):
             return None if is_session else self._notification
 
-        from panel.io.notifications import NotificationArea
         js_events = {}
         if config.ready_notification:
             js_events['document_ready'] = {'type': 'success', 'message': config.ready_notification, 'duration': 3000}
         if config.disconnect_notification:
             js_events['connection_lost'] = {'type': 'error', 'message': config.disconnect_notification}
-        self._notifications[self.curdoc] = notifications = NotificationArea(js_events=js_events)
+
+        if _state._notification_type is None:
+            from panel.io.notifications import NotificationArea
+            _state._notification_type = NotificationArea
+        notifications = _state._notification_type(js_events=js_events)
+        self._notifications[self.curdoc] = notifications
         return notifications
 
     @property
