@@ -13,7 +13,7 @@ import param
 from bokeh.models import ColumnDataSource
 from pyviz_comms import JupyterComm
 
-from ..util import lazy_load
+from ..util import lazy_load, try_datetime64_to_datetime
 from ..util.checks import datetime_types, isdatetime
 from ..viewable import Layoutable
 from .base import ModelPane
@@ -156,7 +156,7 @@ class Plotly(ModelPane):
     def _update_figure(self):
         import plotly.graph_objs as go
 
-        if (self.object is None or type(self.object) not in (go.Figure, go.FigureWidget) or
+        if (self.object is None or not isinstance(self.object, (go.Figure, go.FigureWidget)) or
             self.object is self._figure or not self.link_figure):
             return
 
@@ -250,28 +250,37 @@ class Plotly(ModelPane):
         return update_sources
 
     @staticmethod
-    def _plotly_json_wrapper(fig):
+    def _convert_trace(trace):
+        trace = dict(trace)
+        for key in trace:
+            if not isdatetime(trace[key]):
+                continue
+            arr = trace[key]
+            if isinstance(arr, np.ndarray):
+                if arr.dtype.kind == 'M' and arr.ndim == 2 and arr.shape[1] == 1:
+                    arr = np.array([[str(try_datetime64_to_datetime(v[0]))] for v in arr])
+                else:
+                    arr = arr.astype(str)
+            elif isinstance(arr, datetime_types):
+                arr = str(arr)
+            else:
+                arr = [str(v) for v in arr]
+            trace[key] = arr
+        return trace
+
+    @classmethod
+    def _plotly_json_wrapper(cls, fig):
         """Wraps around to_plotly_json and applies necessary fixes.
 
         For #382: Map datetime elements to strings.
         """
-        json = fig.to_plotly_json()
-        layout = json['layout']
-        data = json['data']
-        shapes = layout.get('shapes', [])
-        for trace in data+shapes:
-            for key in trace:
-                if not isdatetime(trace[key]):
-                    continue
-                arr = trace[key]
-                if isinstance(arr, np.ndarray):
-                    arr = arr.astype(str)
-                elif isinstance(arr, datetime_types):
-                    arr = str(arr)
-                else:
-                    arr = [str(v) for v in arr]
-                trace[key] = arr
-        return json
+        layout = dict(fig._layout)
+        data = [cls._convert_trace(trace) for trace in fig._data]
+        if 'shapes' in layout:
+            layout['shapes'] = [
+                cls._convert_trace(shape) for shape in layout['shapes']
+            ]
+        return {'data': data, 'layout': layout}
 
     def _init_params(self):
         viewport_params = [p for p in self.param if 'viewport' in p]
